@@ -2,16 +2,19 @@
 
 from enum import IntEnum
 
-# pylint: disable=unused-import
 from .protocol_14 import (  # noqa: F401
     INTERNAL_COMMAND_TYPE,
     STRICT_SYSTEM_COMMAND_TYPES,
     VALID_SYSTEM_COMMAND_TYPES,
     Command,
-    IncomingMessageHandler as IncomingMessageHandler14,
-    OutgoingMessageHandler as OutgoingMessageHandler14,
     Stream,
 )
+from .protocol_14 import (
+    IncomingMessageHandler as IncomingMessageHandler14,
+)
+from .protocol_14 import (
+    OutgoingMessageHandler as OutgoingMessageHandler14,
+)
 
 
 class IncomingMessageHandler(IncomingMessageHandler14):
